import { defineComponent } from 'vue'
import { CellGroup, Field, Button, CountDown, Row, Col, showToast } from 'vant'
import ImgCode from '@/components/o-img-code'
import { checkPhone } from '@/helpers/validate'
import request from '../request-music'
import { setLogin, state } from '../state-music'
import { removeAuth, setAuth } from './utils'
import styles from './index.module.less'

type loginType = 'PWD' | 'SMS'
export default defineComponent({
  name: 'login-music',
  data() {
    return {
      loginType: 'SMS' as loginType,
      username: '',
      password: '',
      smsCode: '',
      countDownStatus: true, // 是否发送验证码
      countDownTime: 1000 * 120, // 倒计时时间
      // countDownRef: null as any, // 倒计时实例
      imgCodeStatus: false
    }
  },
  computed: {
    codeDisable() {
      let status = true
      this.username && this.smsCode && (status = false)
      return status
    }
  },
  mounted() {
    removeAuth()
    this.directNext()
  },
  methods: {
    directNext() {
      if (state.user.status === 'login' || state.user.status === 'error') {
        const { returnUrl, isRegister, ...rest } = this.$route.query
        this.$router.replace({
          path: returnUrl as any,
          query: {
            ...rest
          }
        })
      }
    },
    async onLogin() {
      try {
        // let res: any
        const forms: any = {
          username: this.username,
          client_id: 'jmedu-student',
          client_secret: 'jmedu-student',
          autoRegister: true,
          password: this.smsCode,
          loginType: 'SMS',
          grant_type: 'SMS'
        }

        const { data } = await request.post('/api-oauth/userlogin', {
          requestType: 'form',
          data: {
            ...forms
          }
        })

        setAuth(data.token_type + ' ' + data.access_token)

        const userCash = await request.get('/api-student/appLoginUser/getUserInfo', {
          initRequest: true // 初始化接口
        })
        setLogin(userCash.data)

        this.directNext()
      } catch {
        //
      }
    },
    async onSendCode() {
      // 发送验证码
      if (!checkPhone(this.username)) {
        return showToast('请输入正确的手机号码')
      }
      this.imgCodeStatus = true
    },
    onCodeSend() {
      this.countDownStatus = false
      this.$nextTick(() => {
        ;(this.$refs.countDownRef as any).start()
      })
    },
    onFinished() {
      this.countDownStatus = true
      ;(this.$refs.countDownRef as any).reset()
    },
    onChange() {
      if (this.loginType === 'PWD') {
        this.loginType = 'SMS'
      } else if (this.loginType === 'SMS') {
        this.loginType = 'PWD'
      }
    }
  },
  render() {
    return (
      <div class={styles.login}>
        <div class={styles.loginTitle}>
          您好，
          <br /> 欢迎使用管乐团学生端
        </div>
        <CellGroup class={styles.margin34} border={false}>
          <Row style={{ marginBottom: '16px' }}>
            <Col span={24} class={styles.formTitle}>
              手机号
            </Col>
            <Col span={24} class="van-hairline--bottom">
              <Field
                v-model={this.username}
                name="手机号"
                placeholder="请输入您的手机号"
                type="tel"
                maxlength={11}
              />
            </Col>
          </Row>

          <Row>
            <Col span={24} class={styles.formTitle}>
              验证码
            </Col>
            <Col span={24} class="van-hairline--bottom">
              <Field
                v-model={this.smsCode}
                name="验证码"
                placeholder="请输入验证码"
                type="tel"
                maxlength={6}
                // @ts-ignore
                vSlots={{
                  button: () =>
                    this.countDownStatus ? (
                      <span class={styles.codeText} onClick={this.onSendCode}>
                        获取验证码
                      </span>
                    ) : (
                      <CountDown
                        ref="countDownRef"
                        auto-start={false}
                        time={this.countDownTime}
                        onFinish={this.onFinished}
                        format="ss秒"
                      />
                    )
                }}
              />
            </Col>
          </Row>
        </CellGroup>
        <div class={styles.margin34}>
          <Button round block type="primary" disabled={this.codeDisable} onClick={this.onLogin}>
            提交
          </Button>
        </div>

        {this.imgCodeStatus ? (
          <ImgCode
            v-model:value={this.imgCodeStatus}
            phone={this.username}
            onClose={() => {
              this.imgCodeStatus = false
            }}
            onSendCode={this.onCodeSend}
          />
        ) : null}
      </div>
    )
  }
})
